#!/bin/ksh

#####################################################
# Run the sql query against the selected database   #
# The only modification needed for this procedure   #
# is the sql command itself. This is written in     #
# standard INFORMIX SQL                             #
#####################################################

. $1 
export DBMONEY=.
filext="_$INFORMIXSERVER" 
run_sql()
{
dbaccess sysmaster 2>/dev/null  << !!

unload to /tmp/ifx_buffer$filext.lst
delimiter "	"
select
        'Buffsize'||bufsize::char(12) as queue_name,
        trunc((1-(dskreads/bufreads))*100,4) as read_cache,
        case
                when trunc((1-(dskreads/bufreads))*100,4) > 95 then "OK"
                when trunc((1-(dskreads/bufreads))*100,4) > 90 then "WARN"
                else "LOW"
        end as flag
from sysbufpool
where bufreads > 0
--and bufsize=2048
!!
}   


#######################################################
# Clean up the output from sql                        #
#######################################################

remove_blank_lines()
{
	sed '/rows selected/d' /tmp/ifx_buffer"$filext".lst > /tmp/ifx_buffer"$filext".r.lst
	sed '/^$/d' /tmp/ifx_buffer"$filext".r.lst > /tmp/ifx_buffer"$filext".d.lst
}

######################################################
# Remove the temp files                              #
######################################################

clean_up()
{
	rm -rf /tmp/ifx_buffer"$filext".lst
	rm -rf /tmp/ifx_buffer"$filext".d.lst
	rm -rf /tmp/ifx_buffer"$filext".r.lst
}

#export debug=1 #uncomment this line for extra debugging information
export debug=0 #uncomment this line to remove extra debugging

run_sql
remove_blank_lines 

# If debug is set, send extra information to the agent log as seen in the FOC

if [ $debug == '1' ] 
then
	echo LOG Debugging is switched on
fi

# Don't go into all the table stuffaq.if there is no data returned from the sql statement 
# otherwise the Foglight table will be full of bad data, as when no value is returned
# yet we still echo the details into an integer field, it automatically puts in a 0, which is bad

wc -l /tmp/ifx_buffer"$filext".d.lst | read line_count line_tmp

if [ $line_count != '0' ]  
then
    echo TABLE IFXBuffer


    # This section will have to be modified depending on the sql statement.
    # The number of variables read must equal the number of fields received from
    # the sql statement and also must equal the number of fields in the Foglight table

    while read queue_name read_cache flag
    do
	    echo START_SAMPLE_PERIOD	
	    echo queueName.String.id = $queue_name
	    echo readCache:percent = $read_cache
	    echo flag.StringObservation.obs = $flag
	    echo END_SAMPLE_PERIOD  
    done < /tmp/ifx_buffer"$filext".d.lst
    
    echo END_TABLE
fi

#clean_up
exit 0 
