#!/bin/ksh

#####################################################
# Run the sql query against the selected database   #
# The only modification needed for this procedure   #
# is the sql command itself. This is written in     #
# standard INFORMIX SQL                             #
#####################################################

. $1 
export DBMONEY=.
filext="_$INFORMIXSERVER" 
run_sql()
{
dbaccess sysmaster 2>/dev/null  << !!

unload to /tmp/ifx_dbspaces$filext.lst
delimiter "	"
select
        lpad(d.dbsnum,3,'0')||trim(name) as dbspace,
	round(100*sum(c.nfree)/sum(c.chksize),0)::int as prcfree
from sysdbspaces d, syschunks c
where d.dbsnum = c.dbsnum
group by 1
order by 1
!!
}   


#######################################################
# Clean up the output from sql*plus                   #
#######################################################

remove_blank_lines()
{
	sed '/rows selected/d' /tmp/ifx_dbspaces"$filext".lst > /tmp/ifx_dbspaces"$filext".r.lst
	sed '/^$/d' /tmp/ifx_dbspaces"$filext".r.lst > /tmp/ifx_dbspaces"$filext".d.lst
}

######################################################
# Remove the temp files                              #
######################################################

clean_up()
{
	rm -rf /tmp/ifx_dbspaces"$filext".lst
	rm -rf /tmp/ifx_dbspaces"$filext".d.lst
	rm -rf /tmp/ifx_dbspaces"$filext".r.lst
}

#export debug=1 #uncomment this line for extra debugging information
export debug=0 #uncomment this line to remove extra debugging

run_sql
remove_blank_lines 

# If debug is set, send extra information to the agent log as seen in the FOC

if [ $debug == '1' ] 
then
	echo LOG Debugging is switched on
fi

# Don't go into all the table stuffaq.if there is no data returned from the sql statement 
# otherwise the Foglight table will be full of bad data, as when no value is returned
# yet we still echo the details into an integer field, it automatically puts in a 0, which is bad

wc -l /tmp/ifx_dbspaces"$filext".d.lst | read line_count line_tmp

if [ $line_count != '0' ]  
then
    echo TABLE IFXDBSpaces


    # This section will have to be modified depending on the sql statement.
    # The number of variables read must equal the number of fields received from
    # the sql statement and also must equal the number of fields in the Foglight table

    while read dbspace prcfree
    do
	    echo START_SAMPLE_PERIOD	
	    echo dbspaceName.String.id = $dbspace
	    echo prcfree:percent = $prcfree
	    echo END_SAMPLE_PERIOD  
    done < /tmp/ifx_dbspaces"$filext".d.lst
    
    echo END_TABLE
fi

#clean_up
exit 0 
