#!/bin/ksh

#####################################################
# Run the sql query against the selected database   #
# The only modification needed for this procedure   #
# is the sql command itself. This is written in     #
# standard INFORMIX SQL                             #
#####################################################

. $1 
export DBMONEY=.
filext="_$INFORMIXSERVER" 
run_sql()
{
dbaccess sysmaster 2>/dev/null  << !!

unload to /tmp/ifx_locks_wait$filext.lst
delimiter "	"
select trim(dbsname) as table, count(distinct waiter)::int as waiter
from syslocks
where waiter is not null
and type != 'S'     
group by 1
having count(distinct waiter) > 0
order by 2 desc
!!
}   


#######################################################
# Clean up the output from sql*plus                   #
#######################################################

remove_blank_lines()
{
	sed '/rows selected/d' /tmp/ifx_locks_wait"$filext".lst > /tmp/ifx_locks_wait"$filext".r.lst
	sed '/^$/d' /tmp/ifx_locks_wait"$filext".r.lst > /tmp/ifx_locks_wait"$filext".d.lst
}

######################################################
# Remove the temp files                              #
######################################################

clean_up()
{
	rm -rf /tmp/ifx_locks_wait"$filext".lst
	rm -rf /tmp/ifx_locks_wait"$filext".d.lst
	rm -rf /tmp/ifx_locks_wait"$filext".r.lst
}

#export debug=1 #uncomment this line for extra debugging information
export debug=0 #uncomment this line to remove extra debugging

run_sql
remove_blank_lines 

# If debug is set, send extra information to the agent log as seen in the FOC

if [ $debug == '1' ] 
then
	echo LOG Debugging is switched on
fi

# Don't go into all the table stuffaq.if there is no data returned from the sql statement 
# otherwise the Foglight table will be full of bad data, as when no value is returned
# yet we still echo the details into an integer field, it automatically puts in a 0, which is bad

wc -l /tmp/ifx_locks_wait"$filext".d.lst | read line_count line_tmp

if [ $line_count != '0' ]  
then
    echo TABLE IFXLocksW


    # This section will have to be modified depending on the sql statement.
    # The number of variables read must equal the number of fields received from
    # the sql statement and also must equal the number of fields in the Foglight table

    while read tabname waiter
    do
	    echo START_SAMPLE_PERIOD	
	    echo tableName.String.id = $tabname
	    echo waiters:count = $waiter
	    echo END_SAMPLE_PERIOD  
    done < /tmp/ifx_locks_wait"$filext".d.lst
    
    echo END_TABLE
else
    echo TABLE IFXLocksW
	    echo START_SAMPLE_PERIOD	
	    echo tableName.String.id = "n/a"
	    echo waiters:count = 0
	    echo END_SAMPLE_PERIOD  
    echo END_TABLE
fi

#clean_up
exit 0 
