#!/bin/ksh

#####################################################
# Run the sql query against the selected database   #
# The only modification needed for this procedure   #
# is the sql command itself. This is written in     #
# standard INFORMIX SQL                             #
#####################################################

. $1 
export DBMONEY=.
filext="_$INFORMIXSERVER" 
run_sql()
{
dbaccess sysmaster 2>/dev/null  << !!

unload to /tmp/ifx_transactions$filext.lst
delimiter "	"
SELECT  r.username, max(l.uniqid - x.loguniq) as logspan
FROM    systxptab as x, sysrstcb as r, syslogfil as l
WHERE   x.loguniq > 0
AND     x.owner = r.address
AND     bitval(l.flags,'0x2') = 1
GROUP BY 1
having max(l.uniqid - x.loguniq) > 0
!!
}   


#######################################################
# Clean up the output from sql*plus                   #
#######################################################

remove_blank_lines()
{
	sed '/rows selected/d' /tmp/ifx_transactions"$filext".lst > /tmp/ifx_transactions"$filext".r.lst
	sed '/^$/d' /tmp/ifx_transactions"$filext".r.lst > /tmp/ifx_transactions"$filext".d.lst
}

######################################################
# Remove the temp files                              #
######################################################

clean_up()
{
	rm -rf /tmp/ifx_transactions"$filext".lst
	rm -rf /tmp/ifx_transactions"$filext".d.lst
	rm -rf /tmp/ifx_transactions"$filext".r.lst
}

#export debug=1 #uncomment this line for extra debugging information
export debug=0 #uncomment this line to remove extra debugging

run_sql
remove_blank_lines 

# If debug is set, send extra information to the agent log as seen in the FOC

if [ $debug == '1' ] 
then
	echo LOG Debugging is switched on
fi

# Don't go into all the table stuffaq.if there is no data returned from the sql statement 
# otherwise the Foglight table will be full of bad data, as when no value is returned
# yet we still echo the details into an integer field, it automatically puts in a 0, which is bad

wc -l /tmp/ifx_transactions"$filext".d.lst | read line_count line_tmp

if [ $line_count != '0' ]  
then
    echo TABLE IFXLogSpan


    # This section will have to be modified depending on the sql statement.
    # The number of variables read must equal the number of fields received from
    # the sql statement and also must equal the number of fields in the Foglight table

    while read username logspan
    do
	    echo START_SAMPLE_PERIOD	
	    echo userName.String.id = $username
	    echo logspan = $logspan
	    echo END_SAMPLE_PERIOD  
    done < /tmp/ifx_transactions"$filext".d.lst
    
    echo END_TABLE
else
echo TABLE IFXLogSpan

	    echo START_SAMPLE_PERIOD	
	    echo userName.String.id = "n/a"
	    echo logspan = 0
	    echo END_SAMPLE_PERIOD  
    echo END_TABLE
fi

#clean_up
exit 0 
